<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\AdminRequest;
use App\Models\Admin;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class AdminController extends Controller
{
    public $resource = 'admin';
    public $route = 'admins';

    public function __construct()
    {
        view()->share('item', $this->resource);
        view()->share('route', $this->route);
    }

    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $admins = Admin::query()->where('id','!=', 1)->paginate(10);
        return view('admin.crud.admin._table',compact('admins'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.crud.admin._create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(AdminRequest $request)
    {
        Admin::query()->create([
            'name'=>$request->name,
            'email'=>$request->email,
            'password'=>$request->password,
        ]);
        return redirect()->route('dashboard.admins.index')->with('success', 'Admin added successfully');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $admin = Admin::query()->find($id);
        return view('admin.crud.admin._edit',compact('admin'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(AdminRequest $request, string $id)
    {
        $admin = Admin::query()->find($id);
        $admin->update($request->all());
        return redirect()->route('dashboard.admins.index')->with('success', 'Admin updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        Admin::query()->find($id)->delete();
        return redirect()->route('dashboard.admins.index')->with('success', 'Admin deleted successfully');
    }
}
